using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.Diagnostics;
using System.Xml;        // for XmlTextReader and XmlValidatingReader
using System.Xml.Schema; // for XmlSchemaCollection (which is used later)
using System.IO;
using System.Globalization;
using System.Windows.Forms.Design;
using System.Configuration;
using System.Web;

namespace QD_GUI
{
    public partial class MainWindow : Form
    {
        //////////////////////////////////////////////
        // Create object to be constructed from the XML file content
        private QueueDump moQueueDump = new QueueDump();


        // Constructor
        public MainWindow()
        {
            InitializeComponent();
        }

        private void btnRunQD_Click(object sender, EventArgs e)
        {
            // run qd and grab its output
            QueueDumpUtil oQueueDumpUtil = new QueueDumpUtil();
            oQueueDumpUtil.FahDirectory = txtFahDirectory.Text;
            string sOutput = oQueueDumpUtil.Run();

            // check for output
            if (!String.IsNullOrEmpty(sOutput))
            {
                // save the output to a file
                bool isSuccess = false;
                try
                {
                    oQueueDumpUtil.SaveXmlToFile(txtQueueDumpFile.Text);
                    isSuccess = true;
                }
                catch (UnauthorizedAccessException oException)
                {
                    StringBuilder oString = new StringBuilder();
                    oString.Append("Error: You do not have permission to access the file: ");
                    oString.Append(txtQueueDumpFile.Text);
                    oString.Append("\r\n");
                    oString.Append("Select a different location to save the Queue Dump XML File to.\r\n");
                    oString.Append("\r\nError Message:\r\n");
                    oString.Append(oException.Message);

                    MessageBox.Show(oString.ToString());
                    btnQueueDumpBrowse.Focus();

                    isSuccess = false;
                }

                if (isSuccess == true)
                {
                    try
                    {
                        // Parse the XML file and create an object from it
                        moQueueDump = XmlQueueDump.ParseXmlFile(txtQueueDumpFile.Text, moQueueDump);
                        if (!String.IsNullOrEmpty(moQueueDump.Error))
                        {
                            throw new Exception(moQueueDump.Error);
                        }
                        moQueueDump.QDInfo = QDInfo.ParseFile(Properties.Settings.Default.qdinfo_FileName, moQueueDump.QDInfo);

                        // set the controls to the values from the QueueDump object
                        SetControls();

                        // Show a popup with the qd notice messages if present
                        PopupNotice(moQueueDump);
                    }
                    catch (Exception oException)
                    {
                        StringBuilder oString = new StringBuilder();
                        oString.Append("Error: Failed to parse the Queue Dump XML file: ");
                        oString.Append(txtQueueDumpFile.Text);
                        oString.Append("\r\n");
                        oString.Append("\r\nError Message:\r\n");
                        oString.Append(oException.Message);

                        MessageBox.Show(oString.ToString(), "Error");
                    }
                }
            }
        }

        private void btnLoadXML_Click(object sender, EventArgs e)
        {
            try
            {
                moQueueDump = XmlQueueDump.ParseXmlFile(txtQueueDumpFile.Text, moQueueDump);
                if (!String.IsNullOrEmpty(moQueueDump.Error))
                {
                    throw new Exception(moQueueDump.Error);
                }

                // set the controls to the values from the QueueDump object
                SetControls();

                // Show a popup with the qd notice messages if present
                PopupNotice(moQueueDump);
            }
            catch (Exception oException)
            {
                StringBuilder oString = new StringBuilder();
                oString.Append("Error: Failed to parse the Queue Dump XML file: ");
                oString.Append(txtQueueDumpFile.Text);
                oString.Append("\r\n");
                oString.Append("\r\nError Message:\r\n");
                oString.Append(oException.Message);

                MessageBox.Show(oString.ToString(), "Error");
            }
        }

        private void btnFahDirectoryBrowse_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog oFolderBrowserDialog = new FolderBrowserDialog();
            oFolderBrowserDialog.ShowNewFolderButton = false;

            if (!String.IsNullOrEmpty(txtFahDirectory.Text))
            {
                oFolderBrowserDialog.SelectedPath = txtFahDirectory.Text;
            }


            if (oFolderBrowserDialog.ShowDialog() != DialogResult.Cancel)
            {
                txtFahDirectory.Text = oFolderBrowserDialog.SelectedPath;
            }
        }

        private void btnQueueDumpBrowse_Click(object sender, EventArgs e)
        {
            openFileDialogQueueDumpFile.Title = "Select a File";
            openFileDialogQueueDumpFile.InitialDirectory = @"C:\";
            openFileDialogQueueDumpFile.Filter = "All Files|*.*";
            openFileDialogQueueDumpFile.CheckFileExists = false;
            openFileDialogQueueDumpFile.FileName = "qd-output.xml";

            if (!String.IsNullOrEmpty(txtQueueDumpFile.Text))
            {
                int iLastIndex = txtQueueDumpFile.Text.LastIndexOf("\\");
                int iLength = txtQueueDumpFile.Text.Length - (txtQueueDumpFile.Text.Length - iLastIndex);

                string sDirectory = txtQueueDumpFile.Text.Substring(0, iLength);
                string sFilename = txtQueueDumpFile.Text.Substring(iLastIndex + 1);

                openFileDialogQueueDumpFile.InitialDirectory = sDirectory;
                openFileDialogQueueDumpFile.FileName = sFilename;
            }

            if (openFileDialogQueueDumpFile.ShowDialog() != DialogResult.Cancel)
            {
                txtQueueDumpFile.Text = openFileDialogQueueDumpFile.FileName;
            }
        }

        private void SetControls()
        {
            //////////////////////////////////////////////
            // Set the controls on all the tabs

            // Queue Dump - Program Information
            //
            // qd
            // <date>7 February 2008</date>
            if (!String.IsNullOrEmpty(moQueueDump.QD.Date))
            {
                lblQDVersionValue.Text = moQueueDump.QD.Date;
            }
            // <functional_revision>063</functional_revision>
            if (!String.IsNullOrEmpty(moQueueDump.QD.FunctionalRevision))
            {
                lblQDFunctionalRevisionValue.Text = moQueueDump.QD.FunctionalRevision;
            }


            // qdinfo.dat
            // <qdinfo>7 February 2008 (update-qd.pl)</qdinfo>
            if (!String.IsNullOrEmpty(moQueueDump.QDInfo.Date))
            {
                StringBuilder oString = new StringBuilder(moQueueDump.QDInfo.Date);
                if (!String.IsNullOrEmpty(moQueueDump.QDInfo.MaintainedBy))
                {
                    oString.AppendFormat(" ({0})", moQueueDump.QDInfo.MaintainedBy);
                }

                lblQDInfoVersionValue.Text = oString.ToString();
            }
            if (!String.IsNullOrEmpty(moQueueDump.QDInfo.FunctionalRevision))
            {
                lblQDInfoFunctionalRevisionAvailableValue.Text = moQueueDump.QDInfo.FunctionalRevision;

                lblQDInfoFunctionalRevisionAvailableText.Visible = true;
                lblQDInfoFunctionalRevisionAvailableCollon.Visible = true;
                lblQDInfoFunctionalRevisionAvailableValue.Visible = true;
            }
            else
            {
                lblQDInfoFunctionalRevisionAvailableText.Visible = false;
                lblQDInfoFunctionalRevisionAvailableCollon.Visible = false;
                lblQDInfoFunctionalRevisionAvailableValue.Visible = false;
            }

            // Queue Dump - Queue
            //
            // Queue container
            if (!String.IsNullOrEmpty(moQueueDump.Queue.Version))
            {
                lblQueueVersionValue.Text = moQueueDump.Queue.Version;
            }
            if (!String.IsNullOrEmpty(moQueueDump.Queue.SystemType))
            {
                lblQueueSystemTypeValue.Text = moQueueDump.Queue.SystemType;
            }
            if (Convert.ToInt32(moQueueDump.Queue.CurrentIndex) >= 0 && Convert.ToInt32(moQueueDump.Queue.CurrentIndex) <= 9)
            {
                lblQueueCurrentIndexValue.Text = moQueueDump.Queue.CurrentIndex;

                // select the tab for the current index
                int iActiveTab = Convert.ToInt32(moQueueDump.Queue.CurrentIndex) + 1;
                tabctrlQueueDump.SelectedIndex = iActiveTab;
            }

            // download rate container
            if (!String.IsNullOrEmpty(moQueueDump.Queue.DownloadRate.Speed))
            {
                lblDownloadRateSpeedValue.Text = moQueueDump.Queue.DownloadRate.Speed;
            }
            if (!String.IsNullOrEmpty(moQueueDump.Queue.DownloadRate.Units))
            {
                lblDownloadRateUnitsValue.Text = moQueueDump.Queue.DownloadRate.Units;
            }

            // upload rate container
            if (!String.IsNullOrEmpty(moQueueDump.Queue.UploadRate.Speed))
            {
                lblUploadRateSpeedValue.Text = moQueueDump.Queue.UploadRate.Speed;
            }
            if (!String.IsNullOrEmpty(moQueueDump.Queue.UploadRate.Units))
            {
                lblUploadRateUnitsValue.Text = moQueueDump.Queue.UploadRate.Units;
            }

            // performance fraction container
            if (!String.IsNullOrEmpty(moQueueDump.Queue.PerformanceFraction.Fraction))
            {
                lblPerformanceFractionFractionValue.Text = moQueueDump.Queue.PerformanceFraction.Fraction;
            }
            if (!String.IsNullOrEmpty(moQueueDump.Queue.PerformanceFraction.Units))
            {
                lblPerformanceFractionUnitsValue.Text = moQueueDump.Queue.PerformanceFraction.Units;
            }

            // point projection container
            if (!String.IsNullOrEmpty(moQueueDump.Queue.PPH))
            {
                lblPointsPerHourValue.Text = moQueueDump.Queue.PPH;
            }
            if (!String.IsNullOrEmpty(moQueueDump.Queue.PPD))
            {
                lblPointsPerDayValue.Text = moQueueDump.Queue.PPD;
            }
            if (!String.IsNullOrEmpty(moQueueDump.Queue.PPW))
            {
                lblPointsPerWeekValue.Text = moQueueDump.Queue.PPW;
            }
            if (!String.IsNullOrEmpty(moQueueDump.Queue.PPY))
            {
                lblPointsPerYearValue.Text = moQueueDump.Queue.PPY;
            }

            // Tabs: Index 0 - Index 9
            // queue indices
	        for (int i = 0; i <= 9; i++)
	        {
                // Tab: Index 0
                // queue index 0
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Status))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 1:
                            lblIndex1GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 2:
                            lblIndex2GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 3:
                            lblIndex3GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 4:
                            lblIndex4GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 5:
                            lblIndex5GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 6:
                            lblIndex6GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 7:
                            lblIndex7GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 8:
                            lblIndex8GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                        case 9:
                            lblIndex9GeneralStatusValue.Text = moQueueDump.Queue.Index[i].Status;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].ProjectNumber))
                {
                    if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].ProjectName))
                    {
                        StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].ProjectNumber);
                        oString.Append(" \"");
                        oString.Append(moQueueDump.Queue.Index[i].ProjectName);
                        oString.Append("\"");

                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8GeneralProjectValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9GeneralProjectValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 1:
                                lblIndex1GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 2:
                                lblIndex2GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 3:
                                lblIndex3GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 4:
                                lblIndex4GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 5:
                                lblIndex5GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 6:
                                lblIndex6GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 7:
                                lblIndex1GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 8:
                                lblIndex8GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                            case 9:
                                lblIndex9GeneralProjectValue.Text = moQueueDump.Queue.Index[i].ProjectNumber;
                                break;
                        }                    
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Points))
                {
                    if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].PointsPerHour))
                    {
                        StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].Points);
                        oString.Append(" (");
                        oString.Append(moQueueDump.Queue.Index[i].PointsPerHour);
                        oString.Append(" points/hour)");

                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8GeneralPointsValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9GeneralPointsValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 1:
                                lblIndex1GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 2:
                                lblIndex2GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 3:
                                lblIndex3GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 4:
                                lblIndex4GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 5:
                                lblIndex5GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 6:
                                lblIndex6GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 7:
                                lblIndex7GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 8:
                                lblIndex8GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                            case 9:
                                lblIndex9GeneralPointsValue.Text = moQueueDump.Queue.Index[i].Points;
                                break;
                        }
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Progress))
                {
                    if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].ProgressRate))
                    {
                        StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].Progress);
                        oString.Append(" (");
                        oString.Append(moQueueDump.Queue.Index[i].ProgressRate);
                        oString.Append(" X min speed)");

                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9GeneralProgressValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 1:
                                lblIndex1GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 2:
                                lblIndex2GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 3:
                                lblIndex3GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 4:
                                lblIndex4GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 5:
                                lblIndex5GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 6:
                                lblIndex6GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 7:
                                lblIndex7GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 8:
                                lblIndex8GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                            case 9:
                                lblIndex9GeneralProgressValue.Text = moQueueDump.Queue.Index[i].Progress;
                                break;
                        }
                    }
                }
                else if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].ProgressRate))
                {
                    StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].ProgressRate);
                    oString.Append(" X min speed");

                    switch (i)
                    {
                        case 0:
                            lblIndex0GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 1:
                            lblIndex1GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 2:
                            lblIndex2GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 3:
                            lblIndex3GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 4:
                            lblIndex4GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 5:
                            lblIndex5GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 6:
                            lblIndex6GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 7:
                            lblIndex7GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 8:
                            lblIndex8GeneralProgressValue.Text = oString.ToString();
                            break;
                        case 9:
                            lblIndex9GeneralProgressValue.Text = oString.ToString();
                            break;
                    }
                }

                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Server[0].Number))
                {
                    switch (moQueueDump.Queue.Index[i].Server[0].Number)
                    {
                        case "1":
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 1:
                                    lblIndex1GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 2:
                                    lblIndex2GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 3:
                                    lblIndex3GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 4:
                                    lblIndex4GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 5:
                                    lblIndex5GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 6:
                                    lblIndex6GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 7:
                                    lblIndex7GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 8:
                                    lblIndex8GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 9:
                                    lblIndex9GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                            }
                            break;
                        case "2":
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 1:
                                    lblIndex1GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 2:
                                    lblIndex2GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 3:
                                    lblIndex3GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 4:
                                    lblIndex4GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 5:
                                    lblIndex5GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 6:
                                    lblIndex6GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 7:
                                    lblIndex7GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 8:
                                    lblIndex8GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                                case 9:
                                    lblIndex9GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[0].Address;
                                    break;
                            }
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Server[1].Number))
                {
                    switch (moQueueDump.Queue.Index[i].Server[1].Number)
                    {
                        case "1":
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 1:
                                    lblIndex1GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 2:
                                    lblIndex2GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 3:
                                    lblIndex3GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 4:
                                    lblIndex4GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 5:
                                    lblIndex5GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 6:
                                    lblIndex6GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 7:
                                    lblIndex7GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 8:
                                    lblIndex8GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 9:
                                    lblIndex9GeneralServer1Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                            }
                            break;
                        case "2":
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 1:
                                    lblIndex1GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 2:
                                    lblIndex2GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 3:
                                    lblIndex3GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 4:
                                    lblIndex4GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 5:
                                    lblIndex5GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 6:
                                    lblIndex6GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 7:
                                    lblIndex7GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 8:
                                    lblIndex8GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                                case 9:
                                    lblIndex9GeneralServer2Value.Text = moQueueDump.Queue.Index[i].Server[1].Address;
                                    break;
                            }
                            break;
                    }
                }

                // tag: P2146R0C442F49
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Tag))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 1:
                            lblIndex1GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 2:
                            lblIndex2GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 3:
                            lblIndex3GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 4:
                            lblIndex4GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 5:
                            lblIndex5GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 6:
                            lblIndex6GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 7:
                            lblIndex7GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 8:
                            lblIndex8GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                        case 9:
                            lblIndex9GeneralTagValue.Text = moQueueDump.Queue.Index[i].Tag;
                            break;
                    }
                }

                // Folding: run 1, clone 19, generation 4; benchmark 797; misc: 500, 300
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Run)
                   || !String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Clone)
                   || !String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Generation)
                   )
                {
                    StringBuilder oString = new StringBuilder();
                    oString.AppendFormat("Run: {0}, ", moQueueDump.Queue.Index[i].Folding.Run);
                    oString.AppendFormat("Clone: {0}, ", moQueueDump.Queue.Index[i].Folding.Clone);
                    oString.AppendFormat("Generation: {0}", moQueueDump.Queue.Index[i].Folding.Generation);

                    switch (i)
                    {
                        case 0:
                            lblIndex0FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 1:
                            lblIndex1FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 2:
                            lblIndex2FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 3:
                            lblIndex3FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 4:
                            lblIndex4FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 5:
                            lblIndex5FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 6:
                            lblIndex6FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 7:
                            lblIndex7FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 8:
                            lblIndex8FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                        case 9:
                            lblIndex9FoldingTrajectoryValue.Text = oString.ToString();
                            break;
                    }
                    
                    // benchmark 797;
                    if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Benchmark))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 1:
                                lblIndex1FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 2:
                                lblIndex2FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 3:
                                lblIndex3FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 4:
                                lblIndex4FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 5:
                                lblIndex5FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 6:
                                lblIndex6FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 7:
                                lblIndex7FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 8:
                                lblIndex8FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                            case 9:
                                lblIndex9FoldingBenchmarkValue.Text = moQueueDump.Queue.Index[i].Folding.Benchmark;
                                break;
                        }
                    }

                    // misc: 500, 300
                    if (  !String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Misc)
                       || !String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Other)
                       )
                    {
                        oString = new StringBuilder();
                        if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Misc))
                        {
                            oString.Append(moQueueDump.Queue.Index[i].Folding.Misc);

                            if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Other))
                            {
                                oString.Append(", " + moQueueDump.Queue.Index[i].Folding.Other);
                            }
                        }
                        else if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Other))
                        {
                            oString.Append(moQueueDump.Queue.Index[i].Folding.Other);
                        }

                        switch (i)
                        {
                            case 0:
                                lblIndex0FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9FoldingMiscellaneousValue.Text = oString.ToString();
                                break;
                        }
                    }
                }
                // Genome: unit 36476, 7554, 656; benchmark 739; misc: 500, 200
                else if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Unit))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 1:
                            lblIndex1GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 2:
                            lblIndex2GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 3:
                            lblIndex3GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 4:
                            lblIndex4GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 5:
                            lblIndex5GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 6:
                            lblIndex6GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 7:
                            lblIndex7GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 8:
                            lblIndex8GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                        case 9:
                            lblIndex9GenomeUnitValue.Text = moQueueDump.Queue.Index[i].Genome.Unit;
                            break;
                    }
                    
                    // benchmark 739; 
                    if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Benchmark))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 1:
                                lblIndex1GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 2:
                                lblIndex2GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 3:
                                lblIndex3GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 4:
                                lblIndex4GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 5:
                                lblIndex5GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 6:
                                lblIndex6GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 7:
                                lblIndex7GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 8:
                                lblIndex8GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                            case 9:
                                lblIndex9GenomeBenchmarkValue.Text = moQueueDump.Queue.Index[i].Genome.Benchmark;
                                break;
                        }
                    }

                    // misc: 500, 200
                    if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Misc)
                       || !String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Other)
                       )
                    {
                        StringBuilder oString = new StringBuilder();
                        if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Misc))
                        {
                            oString.Append(moQueueDump.Queue.Index[i].Genome.Misc);

                            if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Other))
                            {
                                oString.Append(", " + moQueueDump.Queue.Index[i].Genome.Other);
                            }
                        }
                        else if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Other))
                        {
                            oString.Append(moQueueDump.Queue.Index[i].Genome.Other);
                        }

                        switch (i)
                        {
                            case 0:
                                lblIndex0GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9GenomeMiscellaneousValue.Text = oString.ToString();
                                break;
                        }
                    }
                }
                
                // Hide the Genome control if there is no Genome Unit in the queue index
                if (String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Genome.Unit))
                {
                    switch (i)
                    {
                        case 0:
                            grpbxIndex0Genome.Visible = false;
                            tlpIndex0.Height = (tlpIndex0.Height - grpbxIndex0Genome.Height);
                            break;
                        case 1:
                            grpbxIndex1Genome.Visible = false;
                            tlpIndex1.Height = (tlpIndex1.Height - grpbxIndex1Genome.Height);
                            break;
                        case 2:
                            grpbxIndex2Genome.Visible = false;
                            tlpIndex2.Height = (tlpIndex2.Height - grpbxIndex2Genome.Height);
                            break;
                        case 3:
                            grpbxIndex3Genome.Visible = false;
                            tlpIndex3.Height = (tlpIndex3.Height - grpbxIndex3Genome.Height);
                            break;
                        case 4:
                            grpbxIndex4Genome.Visible = false;
                            tlpIndex4.Height = (tlpIndex4.Height - grpbxIndex4Genome.Height);
                            break;
                        case 5:
                            grpbxIndex5Genome.Visible = false;
                            tlpIndex5.Height = (tlpIndex5.Height - grpbxIndex5Genome.Height);
                            break;
                        case 6:
                            grpbxIndex6Genome.Visible = false;
                            tlpIndex6.Height = (tlpIndex6.Height - grpbxIndex6Genome.Height);
                            break;
                        case 7:
                            grpbxIndex7Genome.Visible = false;
                            tlpIndex7.Height = (tlpIndex7.Height - grpbxIndex7Genome.Height);
                            break;
                        case 8:
                            grpbxIndex8Genome.Visible = false;
                            tlpIndex8.Height = (tlpIndex8.Height - grpbxIndex8Genome.Height);
                            break;
                        case 9:
                            grpbxIndex9Genome.Visible = false;
                            tlpIndex9.Height = (tlpIndex9.Height - grpbxIndex9Genome.Height);
                            break;
                    }
                }
                // Hide the Genome control if there is no Genome Unit in the queue index
                if ( String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Run)
                  && String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Clone)
                  && String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Folding.Generation)
                    ) 
                {
                    switch (i)
                    {
                        case 0:
                            grpbxIndex0Folding.Visible = false;
                            tlpIndex0.Height = (tlpIndex0.Height - grpbxIndex0Folding.Height);
                            break;
                        case 1:
                            grpbxIndex1Folding.Visible = false;
                            tlpIndex1.Height = (tlpIndex1.Height - grpbxIndex1Folding.Height);
                            break;
                        case 2:
                            grpbxIndex2Folding.Visible = false;
                            tlpIndex2.Height = (tlpIndex2.Height - grpbxIndex2Folding.Height);
                            break;
                        case 3:
                            grpbxIndex3Folding.Visible = false;
                            tlpIndex3.Height = (tlpIndex3.Height - grpbxIndex3Folding.Height);
                            break;
                        case 4:
                            grpbxIndex4Folding.Visible = false;
                            tlpIndex4.Height = (tlpIndex4.Height - grpbxIndex4Folding.Height);
                            break;
                        case 5:
                            grpbxIndex5Folding.Visible = false;
                            tlpIndex5.Height = (tlpIndex5.Height - grpbxIndex5Folding.Height);
                            break;
                        case 6:
                            grpbxIndex6Folding.Visible = false;
                            tlpIndex6.Height = (tlpIndex6.Height - grpbxIndex6Folding.Height);
                            break;
                        case 7:
                            grpbxIndex7Folding.Visible = false;
                            tlpIndex7.Height = (tlpIndex7.Height - grpbxIndex7Folding.Height);
                            break;
                        case 8:
                            grpbxIndex8Folding.Visible = false;
                            tlpIndex8.Height = (tlpIndex8.Height - grpbxIndex8Folding.Height);
                            break;
                        case 9:
                            grpbxIndex9Folding.Visible = false;
                            tlpIndex9.Height = (tlpIndex9.Height - grpbxIndex9Folding.Height);
                            break;
                    }
                }
                
                // issue: Mon Aug  9 23:36:42 2004; begin: Mon Aug  9 23:41:10 2004
                // end: Sun Aug 15 18:19:58 2004; due: Thu Aug 26 23:41:10 2004 (17 days)
                //
                // issue: Fri Aug 27 13:06:35 2004; begin: Fri Aug 27 13:06:47 2004
                // end: Sat Aug 28 17:45:24 2004
                //
                // issue: Sat Sep 18 01:47:03 2004; begin: Sat Sep 18 01:47:11 2004
                // end: Wed Sep 22 16:14:20 2004; expire: Sat Oct  2 01:47:11 2004 (14 days)
                // 
                // issue: Wed Sep 22 16:16:20 2004; begin: Wed Sep 22 16:16:56 2004
                // expect: Tue Sep 28 22:59:03 2004; due: Thu Oct 28 15:16:56 2004 (36 days)

                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].IssueTimestamp))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 1:
                            lblIndex1DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 2:
                            lblIndex2DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 3:
                            lblIndex3DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 4:
                            lblIndex4DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 5:
                            lblIndex5DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 6:
                            lblIndex6DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 7:
                            lblIndex7DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 8:
                            lblIndex8DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                        case 9:
                            lblIndex9DateIssueValue.Text = moQueueDump.Queue.Index[i].IssueTimestamp;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].BeginTimestamp))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 1:
                            lblIndex1DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 2:
                            lblIndex2DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 3:
                            lblIndex3DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 4:
                            lblIndex4DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 5:
                            lblIndex5DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 6:
                            lblIndex6DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 7:
                            lblIndex7DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 8:
                            lblIndex8DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                        case 9:
                            lblIndex9DateBeginValue.Text = moQueueDump.Queue.Index[i].BeginTimestamp;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].EndTimestamp))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 1:
                            lblIndex1DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 2:
                            lblIndex2DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 3:
                            lblIndex3DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 4:
                            lblIndex4DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 5:
                            lblIndex5DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 6:
                            lblIndex6DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 7:
                            lblIndex7DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 8:
                            lblIndex8DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                        case 9:
                            lblIndex9DateEndValue.Text = moQueueDump.Queue.Index[i].EndTimestamp;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].ExpectTimestamp))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 1:
                            lblIndex1DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 2:
                            lblIndex2DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 3:
                            lblIndex3DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 4:
                            lblIndex4DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 5:
                            lblIndex5DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 6:
                            lblIndex6DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 7:
                            lblIndex7DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 8:
                            lblIndex8DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                        case 9:
                            lblIndex9DateExpectValue.Text = moQueueDump.Queue.Index[i].ExpectTimestamp;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].DueTimestamp))
                {
                    if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Deadline))
                    {
                        StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].DueTimestamp);
                        oString.AppendFormat(" ({0})", moQueueDump.Queue.Index[i].Deadline);

                        switch (i)
                        {
                            case 0:
                                lblIndex0DateDueValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1DateDueValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2DateDueValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3DateDueValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4DateDueValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5DateDueValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6DateDueValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7DateDueValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8DateDueValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9DateDueValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 1:
                                lblIndex1DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 2:
                                lblIndex2DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 3:
                                lblIndex3DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 4:
                                lblIndex4DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 5:
                                lblIndex5DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 6:
                                lblIndex6DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 7:
                                lblIndex7DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 8:
                                lblIndex8DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                            case 9:
                                lblIndex9DateDueValue.Text = moQueueDump.Queue.Index[i].DueTimestamp;
                                break;
                        }
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].ExpireTimestamp))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 1:
                            lblIndex1DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 2:
                            lblIndex2DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 3:
                            lblIndex3DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 4:
                            lblIndex4DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 5:
                            lblIndex5DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 6:
                            lblIndex6DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 7:
                            lblIndex7DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 8:
                            lblIndex8DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                        case 9:
                            lblIndex9DateExpireValue.Text = moQueueDump.Queue.Index[i].ExpireTimestamp;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].PreferredTimestamp))
                {
                    StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].PreferredTimestamp);
                    oString.AppendFormat(" ({0})", moQueueDump.Queue.Index[i].PreferredDeadline);

                    switch (i)
                    {
                        case 0:
                            lblIndex0DatePreferredValue.Text = oString.ToString();
                            break;
                        case 1:
                            lblIndex1DatePreferredValue.Text = oString.ToString();
                            break;
                        case 2:
                            lblIndex2DatePreferredValue.Text = oString.ToString();
                            break;
                        case 3:
                            lblIndex3DatePreferredValue.Text = oString.ToString();
                            break;
                        case 4:
                            lblIndex4DatePreferredValue.Text = oString.ToString();
                            break;
                        case 5:
                            lblIndex5DatePreferredValue.Text = oString.ToString();
                            break;
                        case 6:
                            lblIndex6DatePreferredValue.Text = oString.ToString();
                            break;
                        case 7:
                            lblIndex7DatePreferredValue.Text = oString.ToString();
                            break;
                        case 8:
                            lblIndex8DatePreferredValue.Text = oString.ToString();
                            break;
                        case 9:
                            lblIndex9DatePreferredValue.Text = oString.ToString();
                            break;
                    }
                }

                // core URL: http://www.stanford.edu/~pande/Linux/x86/Core_78.fah (V1.68)
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Core.URL))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 1:
                            lblIndex1CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 2:
                            lblIndex2CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 3:
                            lblIndex3CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 4:
                            lblIndex4CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 5:
                            lblIndex5CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 6:
                            lblIndex6CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 7:
                            lblIndex7CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 8:
                            lblIndex8CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                        case 9:
                            lblIndex9CoreUrlValue.Text = moQueueDump.Queue.Index[i].Core.URL;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Core.Version))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 1:
                            lblIndex1CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 2:
                            lblIndex2CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 3:
                            lblIndex3CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 4:
                            lblIndex4CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 5:
                            lblIndex5CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 6:
                            lblIndex6CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 7:
                            lblIndex7CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 8:
                            lblIndex8CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                        case 9:
                            lblIndex9CoreVersionValue.Text = moQueueDump.Queue.Index[i].Core.Version;
                            break;
                    }
                }

                // CPU: 1,0 x86; OS: 4,0 Linux
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].CPU.CosmType))
                {
                    StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].CPU.CosmType);
                    oString.Append(",");
                    oString.Append(moQueueDump.Queue.Index[i].CPU.CosmSubtype);

                    switch (i)
                    {
                        case 0:
                            lblIndex0CPUTypeValue.Text = oString.ToString();
                            break;
                        case 1:
                            lblIndex1CPUTypeValue.Text = oString.ToString();
                            break;
                        case 2:
                            lblIndex2CPUTypeValue.Text = oString.ToString();
                            break;
                        case 3:
                            lblIndex3CPUTypeValue.Text = oString.ToString();
                            break;
                        case 4:
                            lblIndex4CPUTypeValue.Text = oString.ToString();
                            break;
                        case 5:
                            lblIndex5CPUTypeValue.Text = oString.ToString();
                            break;
                        case 6:
                            lblIndex6CPUTypeValue.Text = oString.ToString();
                            break;
                        case 7:
                            lblIndex7CPUTypeValue.Text = oString.ToString();
                            break;
                        case 8:
                            lblIndex8CPUTypeValue.Text = oString.ToString();
                            break;
                        case 9:
                            lblIndex9CPUTypeValue.Text = oString.ToString();
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].CPU.Name))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 1:
                            lblIndex1CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 2:
                            lblIndex2CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 3:
                            lblIndex3CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 4:
                            lblIndex4CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 5:
                            lblIndex5CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 6:
                            lblIndex6CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 7:
                            lblIndex7CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 8:
                            lblIndex8CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                        case 9:
                            lblIndex9CPUNameValue.Text = moQueueDump.Queue.Index[i].CPU.Name;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].OS.CosmType))
                {
                    StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].OS.CosmType);
                    oString.Append(",");
                    oString.Append(moQueueDump.Queue.Index[i].OS.CosmSubtype);

                    switch (i)
                    {
                        case 0:
                            lblIndex0OSTypeValue.Text = oString.ToString();
                            break;
                        case 1:
                            lblIndex1OSTypeValue.Text = oString.ToString();
                            break;
                        case 2:
                            lblIndex2OSTypeValue.Text = oString.ToString();
                            break;
                        case 3:
                            lblIndex3OSTypeValue.Text = oString.ToString();
                            break;
                        case 4:
                            lblIndex4OSTypeValue.Text = oString.ToString();
                            break;
                        case 5:
                            lblIndex5OSTypeValue.Text = oString.ToString();
                            break;
                        case 6:
                            lblIndex6OSTypeValue.Text = oString.ToString();
                            break;
                        case 7:
                            lblIndex7OSTypeValue.Text = oString.ToString();
                            break;
                        case 8:
                            lblIndex8OSTypeValue.Text = oString.ToString();
                            break;
                        case 9:
                            lblIndex9OSTypeValue.Text = oString.ToString();
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].OS.Name))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 1:
                            lblIndex1OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 2:
                            lblIndex2OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 3:
                            lblIndex3OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 4:
                            lblIndex4OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 5:
                            lblIndex5OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 6:
                            lblIndex6OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 7:
                            lblIndex7OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 8:
                            lblIndex8OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                        case 9:
                            lblIndex9OSNameValue.Text = moQueueDump.Queue.Index[i].OS.Name;
                            break;
                    }
                }

                // smp cores: 4
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].SMPCores))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 1:
                            lblIndex1CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 2:
                            lblIndex2CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 3:
                            lblIndex3CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 4:
                            lblIndex4CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 5:
                            lblIndex5CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 6:
                            lblIndex6CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 7:
                            lblIndex7CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 8:
                            lblIndex8CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                        case 9:
                            lblIndex9CPUSMPCoresValue.Text = moQueueDump.Queue.Index[i].SMPCores;
                            break;
                    }
                }

                // assignment info (le): Mon Aug  9 23:36:38 2004; AC1213B0
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 1:
                            lblIndex1AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 2:
                            lblIndex2AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 3:
                            lblIndex3AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 4:
                            lblIndex4AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 5:
                            lblIndex5AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 6:
                            lblIndex6AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 7:
                            lblIndex7AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 8:
                            lblIndex8AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                        case 9:
                            lblIndex9AssignmentInfoByteOrderValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 1:
                            lblIndex1AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 2:
                            lblIndex2AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 3:
                            lblIndex3AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 4:
                            lblIndex4AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 5:
                            lblIndex5AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 6:
                            lblIndex6AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 7:
                            lblIndex7AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 8:
                            lblIndex8AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                        case 9:
                            lblIndex9AssignmentInfoTimestampValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].AssignmentInfo.Checksum))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 1:
                            lblIndex1AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 2:
                            lblIndex2AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 3:
                            lblIndex3AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 4:
                            lblIndex4AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 5:
                            lblIndex5AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 6:
                            lblIndex6AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 7:
                            lblIndex7AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 8:
                            lblIndex8AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                        case 9:
                            lblIndex9AssignmentInfoChecksumValue.Text = moQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                            break;
                    }
                }

                // user: rph_iv; team: 0; ID: 3539220A7A46065D; mach ID: 1
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Username))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 1:
                            lblIndex1ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 2:
                            lblIndex2ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 3:
                            lblIndex3ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 4:
                            lblIndex4ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 5:
                            lblIndex5ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 6:
                            lblIndex6ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 7:
                            lblIndex7ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 8:
                            lblIndex8ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                        case 9:
                            lblIndex9ConfigurationUsernameValue.Text = moQueueDump.Queue.Index[i].Username;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].Team))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 1:
                            lblIndex1ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 2:
                            lblIndex2ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 3:
                            lblIndex3ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 4:
                            lblIndex4ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 5:
                            lblIndex5ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 6:
                            lblIndex6ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 7:
                            lblIndex7ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 8:
                            lblIndex8ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                        case 9:
                            lblIndex9ConfigurationTeamValue.Text = moQueueDump.Queue.Index[i].Team;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].ID))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 1:
                            lblIndex1ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 2:
                            lblIndex2ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 3:
                            lblIndex3ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 4:
                            lblIndex4ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 5:
                            lblIndex5ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 6:
                            lblIndex6ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 7:
                            lblIndex7ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 8:
                            lblIndex8ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                        case 9:
                            lblIndex9ConfigurationIDValue.Text = moQueueDump.Queue.Index[i].ID;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].MachineID))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 1:
                            lblIndex1ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 2:
                            lblIndex2ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 3:
                            lblIndex3ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 4:
                            lblIndex4ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 5:
                            lblIndex5ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 6:
                            lblIndex6ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 7:
                            lblIndex7ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 8:
                            lblIndex8ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                        case 9:
                            lblIndex9ConfigurationMachineIDValue.Text = moQueueDump.Queue.Index[i].MachineID;
                            break;
                    }
                }

                // CS: 171.67.89.100; upload failures: 1; P limit: 5241856
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].CollectionServer))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 1:
                            lblIndex1ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 2:
                            lblIndex2ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 3:
                            lblIndex3ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 4:
                            lblIndex4ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 5:
                            lblIndex5ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 6:
                            lblIndex6ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 7:
                            lblIndex7ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 8:
                            lblIndex8ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                        case 9:
                            lblIndex9ExtraInfoCollectionServerValue.Text = moQueueDump.Queue.Index[i].CollectionServer;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].UploadFailures))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 1:
                            lblIndex1ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 2:
                            lblIndex2ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 3:
                            lblIndex3ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 4:
                            lblIndex4ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 5:
                            lblIndex5ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 6:
                            lblIndex6ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 7:
                            lblIndex7ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 8:
                            lblIndex8ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                        case 9:
                            lblIndex9ExtraInfoUploadFailuresValue.Text = moQueueDump.Queue.Index[i].UploadFailures;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].PacketSizeLimit))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 1:
                            lblIndex1ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 2:
                            lblIndex2ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 3:
                            lblIndex3ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 4:
                            lblIndex4ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 5:
                            lblIndex5ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 6:
                            lblIndex6ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 7:
                            lblIndex7ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 8:
                            lblIndex8ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                        case 9:
                            lblIndex9ExtraInfoPacketSizeLimitValue.Text = moQueueDump.Queue.Index[i].PacketSizeLimit;
                            break;
                    }
                }
                // DL: Sat Sep 18 01:47:09 2004; upload failures: 1; P limit: 5241856
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].DownloadTimestamp))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 1:
                            lblIndex1ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 2:
                            lblIndex2ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 3:
                            lblIndex3ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 4:
                            lblIndex4ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 5:
                            lblIndex5ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 6:
                            lblIndex6ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 7:
                            lblIndex7ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 8:
                            lblIndex8ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                        case 9:
                            lblIndex9ExtraInfoDownloadedValue.Text = moQueueDump.Queue.Index[i].DownloadTimestamp;
                            break;
                    }
                }

                // work/wudata_07.dat file size: 197433; WU type: Folding@Home
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].WorkUnit.File))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 1:
                            lblIndex1WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 2:
                            lblIndex2WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 3:
                            lblIndex3WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 4:
                            lblIndex4WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 5:
                            lblIndex5WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 6:
                            lblIndex6WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 7:
                            lblIndex7WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 8:
                            lblIndex8WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                        case 9:
                            lblIndex9WorkUnitFileValue.Text = moQueueDump.Queue.Index[i].WorkUnit.File;
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].WorkUnit.Size))
                {
                    StringBuilder oString = new StringBuilder(moQueueDump.Queue.Index[i].WorkUnit.Size);
                    oString.Append(" bytes");

                    switch (i)
                    {
                        case 0:
                            lblIndex0WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 1:
                            lblIndex1WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 2:
                            lblIndex2WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 3:
                            lblIndex3WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 4:
                            lblIndex4WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 5:
                            lblIndex5WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 6:
                            lblIndex6WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 7:
                            lblIndex7WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 8:
                            lblIndex8WorkUnitSizeValue.Text = oString.ToString();
                            break;
                        case 9:
                            lblIndex9WorkUnitSizeValue.Text = oString.ToString();
                            break;
                    }
                }
                if (!String.IsNullOrEmpty(moQueueDump.Queue.Index[i].WorkUnit.Type))
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 1:
                            lblIndex1WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 2:
                            lblIndex2WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 3:
                            lblIndex3WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 4:
                            lblIndex4WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 5:
                            lblIndex5WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 6:
                            lblIndex6WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 7:
                            lblIndex7WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 8:
                            lblIndex8WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                        case 9:
                            lblIndex9WorkUnitTypeValue.Text = moQueueDump.Queue.Index[i].WorkUnit.Type;
                            break;
                    }
                }
		    }
        }

        private void PopupNotice(QueueDump moQueueDump)
        {
            if (moQueueDump.Notice.Count > 0)
            {
                StringBuilder oString = new StringBuilder();
                for (int i = 0; i < moQueueDump.Notice.Count; i++)
                {
                    oString.Append(moQueueDump.Notice[i]);
                    oString.Append("\r\n");
                }
                MessageBox.Show(oString.ToString(), "Notice");
            }
        }

        private void optionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OptionsWindow oOptionsWindow = new OptionsWindow();
            oOptionsWindow.Show();
        }

        private void closeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void checkForUpdatesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            WebUpdateWindow oWebUpdateWindow = new WebUpdateWindow();
            oWebUpdateWindow.Show();

            //WebUpdate oWebUpdate = new WebUpdate();
            //try
            //{
            //    oWebUpdate.Update();
            //}
            //catch (Exception oException)
            //{
            //    StringBuilder oString = new StringBuilder();
            //    oString.Append("Error: WebUpdate failed.\r\n");
            //    oString.Append("\r\n");
            //    oString.Append(oException.Message + ".\r\n");

            //    MessageBox.Show(oString.ToString());

            //}
        }

        private void txtFahDirectory_TextChanged(object sender, EventArgs e)
        {
            //Properties.Settings.Default.FahDirectory = txtFahDirectory.Text;
            //Properties.Settings.Default.Save();
        }

        private void txtQueueDumpFile_TextChanged(object sender, EventArgs e)
        {
            //Properties.Settings.Default.QueueDumpFile = txtQueueDumpFile.Text;
            //Properties.Settings.Default.Save();
        }
    }
}
